<?php
include 'db.php';

$username = "";
$email = "";
$password = "";
$err_msg = "";
$success_msg = "";

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $username = $_POST['username'];
    $email = $_POST['email'];
    $password = $_POST['password'];

    // Input validation
    if (empty($username) || empty($email) || empty($password)) {
        $err_msg = "All fields are required!";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $err_msg = "Invalid email format!";
    } elseif (strlen($password) < 6) {
        $err_msg = "Password should be at least 6 characters!";
    } else {
        // Insert into database without hashing the password
        $stmt = $conn->prepare("INSERT INTO admin (username, email, password) VALUES (?, ?, ?)");
        $stmt->bind_param("sss", $username, $email, $password);

        if ($stmt->execute()) {
            $success_msg = "Registration successful! Redirecting to login page...";
            header("refresh:2; url=admin-login.php");  
            exit();
        } else {
            $err_msg = "Error: " . $stmt->error;
        }

        $stmt->close();
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="description" content="">
  <meta name="author" content="">
  <link rel="icon" href="../../../images/favicon.ico">

  <title>EV Admin - Register</title>

  <!-- Vendors Style-->
  <link rel="stylesheet" href="../src/css/vendors_css.css">
    
  <!-- Style-->  
  <link rel="stylesheet" href="../src/css/style.css">
  <link rel="stylesheet" href="../src/css/skin_color.css">  
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">

</head>
  
<body class="hold-transition theme-primary bg-img" style="background-image: url(../../../images/auth-bg/bg-16.jpg)">
  
  <div class="container h-p100">
    <div class="row align-items-center justify-content-md-center h-p100">  
    
      <div class="col-12">
        <div class="row justify-content-center g-0">
          <div class="col-lg-5 col-md-5 col-12">
            <div class="bg-white rounded10 shadow-lg">
              <div class="content-top-agile p-20 pb-0">
                <h2 class="text-primary fw-600">Let's Get Started</h2>
                <p class="mb-0 text-fade">Register to continue to EV Admin.</p>                            
              </div>
              <div class="p-40">
                <!-- Registration Form -->
                <form action="" method="POST">
    <div class="form-group">
        <div class="input-group mb-3">
            <span class="input-group-text bg-transparent"><i class="bi bi-person text-fade"></i></span>
            <input type="text" class="form-control ps-15 bg-transparent" placeholder="Username" name="username" required value="<?php echo htmlspecialchars($username); ?>">
        </div>
    </div>
    <div class="form-group">
        <div class="input-group mb-3">
            <span class="input-group-text bg-transparent"><i class="bi bi-envelope text-fade"></i></span>
            <input type="email" class="form-control ps-15 bg-transparent" placeholder="Email" name="email" required value="<?php echo htmlspecialchars($email); ?>">
        </div>
    </div>
    <div class="form-group">
        <div class="input-group mb-3">
            <span class="input-group-text bg-transparent"><i class="bi bi-lock text-fade"></i></span>
            <input type="password" class="form-control ps-15 bg-transparent" placeholder="Password" name="password" required>
        </div>
    </div>
    <div class="row">
        <div class="col-12 text-center">
            <button type="submit" class="btn btn-primary w-p100 mt-10">REGISTER</button>
        </div>
    </div>
</form>


                <!-- Display Error or Success Message -->
                <?php if ($err_msg): ?>
                  <div class="alert alert-danger mt-3"><?php echo $err_msg; ?></div>
                <?php endif; ?>
                <?php if ($success_msg): ?>
                  <div class="alert alert-success mt-3"><?php echo $success_msg; ?></div>
                <?php endif; ?>

                <div class="text-center">
                  <p class="mt-15 mb-0 text-fade">Already have an account? <a href="admin-login.php" class="text-primary ms-5">Login</a></p>
                </div>
                
              </div>            
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>

  <!-- Vendor JS -->
  <script src="../src/js/vendors.min.js"></script>
  <script src="../src/js/pages/chat-popup.js"></script>
  <script src="../../../assets/icons/feather-icons/feather.min.js"></script>  

</body>
</html>
