<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST, GET, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type, Authorization");
header("Content-Type: application/json");

include 'db.php'; // Database connection

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Capture incoming data
    $service = $_POST['service'] ?? '';
    $subService = $_POST['subService'] ?? '';
    $date = $_POST['date'] ?? '';
    $time = $_POST['time'] ?? '';
    $firstName = $_POST['firstName'] ?? '';
    $lastName = $_POST['lastName'] ?? '';
    $email = $_POST['email'] ?? '';
    $phone = $_POST['phone'] ?? '';
    $timeOfBirth = $_POST['timeOfBirth'] ?? '';
    $placeOfBirth = $_POST['placeOfBirth'] ?? '';
    $city = $_POST['city'] ?? '';
    $country = $_POST['country'] ?? '';
    $status = 0; // Default status: Pending

    // Insert data into the database
    $stmt = $conn->prepare("INSERT INTO appointment (service, subService, date, time, firstName, lastName, email, phone, timeOfBirth, placeOfBirth, city, country, action) 
                            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
    if ($stmt === false) {
        error_log("SQL Error: " . $conn->error);
        echo json_encode(["message" => "SQL Error: " . $conn->error]);
        exit;
    }

    $stmt->bind_param("sssssssssssss", $service, $subService, $date, $time, $firstName, $lastName, $email, $phone, $timeOfBirth, $placeOfBirth, $city, $country, $status);

    if ($stmt->execute()) {
        $insert_id = $stmt->insert_id;

        // Notify the admin via email
        $admin_email = "gauravbadgujar6353@gmail.com";
        $admin_subject = "New Appointment Inquiry - Approval Required";
        $admin_message = "
        <html>
        <body>
            <p>A new appointment has been submitted. Details:</p>
            <ul>
                <li>Service: $service</li>
                <li>Sub-Service: $subService</li>
                <li>Date: $date</li>
                <li>Time: $time</li>
                <li>First Name: $firstName</li>
                <li>Last Name: $lastName</li>
                <li>Email: $email</li>
                <li>Phone: $phone</li>
            </ul>
        </body>
        </html>";

        $admin_headers = "MIME-Version: 1.0\r\n";
        $admin_headers .= "Content-Type: text/html; charset=UTF-8\r\n";
        $admin_headers .= "From: OHM Holistic Healings <no-reply@ohmhh.com>\r\n";

        mail($admin_email, $admin_subject, $admin_message, $admin_headers);

        // Notify the user via email
        $user_subject = "Appointment Confirmation";
        $user_message = "
        <html>
        <body>
            <p>Dear $firstName $lastName,</p>
            <p>Thank you for booking an appointment with us. Here are your appointment details:</p>
            <ul>
                <li>Service: $service</li>
                <li>Sub-Service: $subService</li>
                <li>Date: $date</li>
                <li>Time: $time</li>
            </ul>
            <p>We will contact you shortly for confirmation.</p>
        </body>
        </html>";

        $user_headers = "MIME-Version: 1.0\r\n";
        $user_headers .= "Content-Type: text/html; charset=UTF-8\r\n";
        $user_headers .= "From: OHM Holistic Healings <no-reply@ohmhh.com>\r\n";

        if (mail($email, $user_subject, $user_message, $user_headers)) {
            echo json_encode(["message" => "Appointment submitted successfully."]);
        } else {
            echo json_encode(["message" => "Appointment submitted, but user email notification failed."]);
        }
    } else {
        error_log("SQL Execute Error: " . $stmt->error);
        echo json_encode(["message" => "Failed to submit appointment."]);
    }

    $stmt->close();
} else {
    echo json_encode(["message" => "Invalid request method."]);
}

// Add the new functionality to send an email based on an existing record
if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $insert_id = $_GET['id'] ?? ''; // Capture the ID from GET parameters

    if (empty($insert_id)) {
        echo json_encode(["message" => "No ID provided for sending email."]);
        exit;
    }

    // Fetch data for the given ID
    $stmt = $conn->prepare("SELECT * FROM appointment WHERE id = ?");
    if ($stmt === false) {
        error_log("SQL Error: " . $conn->error);
        echo json_encode(["message" => "SQL Error: " . $conn->error]);
        exit;
    }

    $stmt->bind_param("i", $insert_id);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $appointment = $result->fetch_assoc();

            $email = $appointment['email'];
            $firstName = $appointment['firstName'];
            $lastName = $appointment['lastName'];
            $service = $appointment['service'];
            $subService = $appointment['subService'];
            $date = $appointment['date'];
            $time = $appointment['time'];

            // Email content
            $user_subject = "Appointment Confirmation (Existing Record)";
            $user_message = "
            <html>
            <body>
                <p>Dear $firstName $lastName,</p>
                <p>Here are your appointment details:</p>
                <ul>
                    <li>Service: $service</li>
                    <li>Sub-Service: $subService</li>
                    <li>Date: $date</li>
                    <li>Time: $time</li>
                </ul>
            </body>
            </html>";

            $user_headers = "MIME-Version: 1.0\r\n";
            $user_headers .= "Content-Type: text/html; charset=UTF-8\r\n";
            $user_headers .= "From: OHM Holistic Healings <no-reply@ohmhh.com>\r\n";

            if (mail($email, $user_subject, $user_message, $user_headers)) {
                echo json_encode(["message" => "Email sent successfully to the user."]);
            } else {
                echo json_encode(["message" => "Failed to send email to the user."]);
            }
        } else {
            echo json_encode(["message" => "No record found for the provided ID."]);
        }
    } else {
        error_log("SQL Execute Error: " . $stmt->error);
        echo json_encode(["message" => "Failed to retrieve appointment."]);
    }

    $stmt->close();
}
?>
