<?php
header("Content-Type: application/json");
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Access-Control-Allow-Headers: Content-Type");

include 'db.php';  

error_reporting(E_ALL);
ini_set('display_errors', 1);

$data = json_decode(file_get_contents('php://input'), true);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $jsonData = file_get_contents('php://input');
    $data = json_decode($jsonData, true);

    if (isset($data['id']) && isset($data['action'])) {
        $id = $data['id'];
        $action = $data['action'];

        if ($action !== 'approve' && $action !== 'reject') {
            echo json_encode(["message" => "Invalid action"]);
            exit;
        }

        $action_value = $action === 'approve' ? 1 : 2;

        // Update action in appointment
        $stmt = $conn->prepare("UPDATE `appointment` SET `action` = ? WHERE `id` = ?");
        if ($stmt === false) {
            echo json_encode(["message" => "Failed to prepare update query"]);
            exit;
        }

        $stmt->bind_param("ii", $action_value, $id);
        $stmt->execute();

// Check if the action was successful
if ($stmt->affected_rows > 0) {
    // Get the user's email and other details
    $stmt = $conn->prepare("SELECT `email`, `firstName`, `lastName`, `service`, `date`, `time`, `id` FROM `appointment` WHERE `id` = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    $appointment = $result->fetch_assoc();

    // Generate appointment number
    $appointmentNumber = "A2A0" . $appointment['id'];

    // Insert the approved_number if the action is 'approve'
    if ($action === 'approve') {
        $stmt = $conn->prepare("UPDATE `appointment` SET `approved_number` = ? WHERE `id` = ?");
        if ($stmt === false) {
            error_log("Error preparing statement for updating approved_number: " . $conn->error);
            echo json_encode(["message" => "Failed to update approved_number"]);
            exit;
        }
        $stmt->bind_param("si", $appointmentNumber, $id);
        $stmt->execute();
        $stmt->close();
    }

    // Email content with HTML formatting for better UI
    $subject = $action === 'approve' ? "Appointment Approved" : "Appointment Rejected";
    $message = "
    <html>
    <head>
        <style>
            body { font-family: Arial, sans-serif; background-color: #f4f4f4; color: #333; }
            .email-container { background-color: #fff; padding: 20px; border-radius: 8px; box-shadow: 0 0 10px rgba(0, 0, 0, 0.1); }
            .email-header { background-color: #f3a240; color: #fff; padding: 10px; text-align: center; border-radius: 5px 5px 0 0; }
            .email-content { margin-top: 20px; }
            .email-content p { font-size: 16px; line-height: 1.6; }
            .appointment-details { margin-top: 20px; padding: 10px; background-color: #fcf7ec; border-radius: 5px; }
            .appointment-details li { margin-bottom: 10px; }
            .footer { margin-top: 30px; font-size: 14px; color: #777; text-align: center; }
            .footer a { color: #f3a240; text-decoration: none; }
        </style>
    </head>
    <body>
        <div class='email-container'>
            <div class='email-header'>
                <h2>{$subject}</h2>
            </div>
            <div class='email-content'>
                <p>Dear {$appointment['firstName']} {$appointment['lastName']},</p>
                <p>Your appointment for the service <strong>'{$appointment['service']}'</strong> has been <strong>{$action}</strong>.</p>
                <p>Your appointment number is: <strong>{$appointmentNumber}</strong></p>
                <div class='appointment-details'>
                    <h3>Appointment Details:</h3>
                    <ul>
                        <li><strong>Service:</strong> {$appointment['service']}</li>
                        <li><strong>Date:</strong> {$appointment['date']}</li>
                        <li><strong>Time:</strong> {$appointment['time']}</li>
                    </ul>
                </div>
                <p>Thank you for choosing our service!</p>
            </div>
            <div class='footer'>
                <p>For more information, visit <a href='https://ohmhh.com/'>our website</a>.</p>
            </div>
        </div>
    </body>
    </html>
    ";

    // Send the email with HTML content
    $email = $appointment['email'];
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-Type: text/html; charset=UTF-8" . "\r\n";
    $headers .= "From: no-reply@yourdomain.com" . "\r\n";
    $headers .= "Reply-To: no-reply@yourdomain.com" . "\r\n";

    if (mail($email, $subject, $message, $headers)) {
        error_log("Status update email sent successfully to: $email");
    } else {
        error_log("Failed to send status update email to: $email");
    }

    // Send JSON response back
    echo json_encode([
        "success" => true,
        "message" => "Appointment status has been successfully {$action}.",
        "appointmentNumber" => $appointmentNumber,
        "details" => [
            "service" => $appointment['service'],
            "date" => $appointment['date'],
            "time" => $appointment['time'],
        ]
    ]);
} else {
    echo json_encode([
        "success" => false,
        "message" => "Failed to update appointment status."
    ]);
}

    } else {
        echo json_encode(["success" => false, "message" => "Invalid data"]);
    }
}
?>
